@@ -3,7 +3,7 @@ use 5.006_002;
 
 use Mouse::Exporter; # enables strict and warnings
 
-our $VERSION = '0.68';
+our $VERSION = '0.69';
 
 use Carp         qw(confess);
 use Scalar::Util qw(blessed);
@@ -160,7 +160,7 @@ Mouse - Moose minus the antlers
 
 =head1 VERSION
 
-This document describes Mouse version 0.68
+This document describes Mouse version 0.69
 
 =head1 SYNOPSIS
 
@@ -195,20 +195,21 @@ This document describes Mouse version 0.68
 
 =head1 DESCRIPTION
 
-L<Moose> is wonderful. B<Use Moose instead of Mouse.>
+L<Moose|Moose> is a postmodern object system for Perl5. Moose is wonderful.
 
 Unfortunately, Moose has a compile-time penalty. Though significant progress
 has been made over the years, the compile time penalty is a non-starter for
 some very specific applications. If you are writing a command-line application
 or CGI script where startup time is essential, you may not be able to use
-Moose. We recommend that you instead use L<HTTP::Engine> and FastCGI for the
-latter, if possible.
+Moose. We recommend that you instead use persistent Perl executing environments
+like C<FastCGI> for the latter, if possible.
 
-Mouse aims to alleviate this by providing a subset of Moose's functionality,
-faster.
+Mouse is a Moose compatible object system, which aims to alleviate this by
+providing a subset of Moose's functionality.
 
 We're also going as light on dependencies as possible. Mouse currently has
-B<no dependencies> except for testing modules.
+B<no dependencies> except for testing modules. Mouse also works without XS,
+although it has an XS backend to make it much faster.
 
 =head2 MOOSE COMPATIBILITY
 
@@ -218,7 +219,7 @@ The Mouse code just runs the test suite 4x faster.
 
 The idea is that, if you need the extra power, you should be able to run
 C<s/Mouse/Moose/g> on your codebase and have nothing break. To that end,
-we have written L<Any::Moose> which will act as Mouse unless Moose is loaded,
+we have written L<Any::Moose|Any::Moose> which will act as Mouse unless Moose is loaded,
 in which case it will act as Moose. Since Mouse is a little sloppier than
 Moose, if you run into weird errors, it would be worth running:
 
