@@ -1,16 +1,14 @@
 package Mouse::PurePerl;
-
-require Mouse::Util;
-
+# The pure Perl backend for Mouse
 package Mouse::Util;
-
 use strict;
 use warnings;
-
-use warnings FATAL => 'redefine'; # to avoid to load Mouse::PurePerl
+use warnings FATAL => 'redefine'; # to avoid to load Mouse::PurePerl twice
 
 use B ();
 
+require Mouse::Util;
+
 
 # taken from Class/MOP.pm
 sub is_valid_class_name {
@@ -779,7 +777,7 @@ Mouse::PurePerl - A Mouse guts in pure Perl
 
 =head1 VERSION
 
-This document describes Mouse version 0.68
+This document describes Mouse version 0.69
 
 =head1 SEE ALSO
 
